Class: Whisper::Parakeet::Params
- Inherits:
-
Object
- Object
- Whisper::Parakeet::Params
- Defined in:
- sig/whisper.rbs
Class Method Summary collapse
Instance Method Summary collapse
- #abort_callback ⇒ (^(Object user_data) -> boolish)?
-
#abort_callback= ⇒ ^(Object user_data) -> boolish
Sets abort callback, called each time before ggml computation starts.
- #abort_callback_user_data ⇒ Object?
-
#abort_callback_user_data= ⇒ Object?
Sets user data passed to the last argument of abort callback.
-
#abort_on { ... } ⇒ void
Call block to determine whether abort or not.
- #audio_ctx ⇒ Integer
-
#audio_ctx= ⇒ Integer
Overwrite the audio context size.
- #duration_ms ⇒ Integer
-
#duration_ms= ⇒ Integer
Audio duration to process in ms.
- #encoder_begin_callback ⇒ (^(Whisper::Parakeet::Context, untyped, Object user_data) -> boolish)?
-
#encoder_begin_callback= ⇒ ^(Whisper::Parakeet::Context, untyped, Object user_data) -> boolish
Sets encoder begin callback, called each time before the encoder starts.
- #encoder_begin_callback_user_data ⇒ Object?
-
#encoder_begin_callback_user_data= ⇒ Object?
Sets user data passed to the last argument of encoder begin callback.
- #n_threads ⇒ Integer
-
#n_threads= ⇒ Integer
Number of threads to use.
- #new_segment_callback ⇒ (^(Whisper::Parakeet::Context, untyped, Integer n_new, Object user_data) -> void)?
-
#new_segment_callback= ⇒ ^(Whisper::Parakeet::Context, untyped, Integer n_new, Object user_data) -> void
Sets new segment callback, called for every newly generated text segment.
- #new_segment_callback_user_data ⇒ Object?
-
#new_segment_callback_user_data= ⇒ Object?
Sets user data passed to the last argument of new segment callback.
- #new_token_callback ⇒ (^(Whisper::Parakeet::Context, untyped, Whisper::Parakeet::Token, Object user_data) -> void)?
-
#new_token_callback= ⇒ ^(Whisper::Parakeet::Context, untyped, Whisper::Parakeet::Token, Object user_data) -> void
Sets token callback, called for every newly predicted token.
- #new_token_callback_user_data ⇒ Object?
-
#new_token_callback_user_data= ⇒ Object?
Sets user data passed to the last argument of token callback.
- #no_context ⇒ true, false
-
#no_context= ⇒ boolish
If
true, does not use past transcription (if any) as context. - #offset_ms ⇒ Integer
-
#offset_ms= ⇒ Integer
Start offset in ms.
-
#on_encoder_begin { ... } ⇒ void
Hook called each time before the encoder starts.
-
#on_new_segment {|arg0| ... } ⇒ void
Hook called on new segment.
-
#on_new_token {|arg0| ... } ⇒ void
Hook called on new token.
-
#on_progress {|progress| ... } ⇒ void
Hook called on progress update.
- #progress_callback ⇒ (^(Whisper::Parakeet::Context, untyped, Integer progress, Object user_data) -> void)?
-
#progress_callback= ⇒ ^(Whisper::Parakeet::Context, untyped, Integer progress, Object user_data) -> void
Sets progress callback, called on each progress update.
- #progress_callback_user_data ⇒ Object?
-
#progress_callback_user_data= ⇒ Object?
Sets user data passed to the last argument of progress callback.
Class Method Details
.new ⇒ Object
721 |
# File 'sig/whisper.rbs', line 721
def self.new: (
|
Instance Method Details
#abort_callback ⇒ (^(Object user_data) -> boolish)?
815 |
# File 'sig/whisper.rbs', line 815
def abort_callback: () -> ((^(Object user_data) -> boolish) | nil)
|
#abort_callback= ⇒ ^(Object user_data) -> boolish
Sets abort callback, called each time before ggml computation starts.
814 |
# File 'sig/whisper.rbs', line 814
def abort_callback=: (^(Object user_data) -> boolish) -> (^(Object user_data) -> boolish)
|
#abort_callback_user_data ⇒ Object?
820 |
# File 'sig/whisper.rbs', line 820
def abort_callback_user_data: () -> Object?
|
#abort_callback_user_data= ⇒ Object?
Sets user data passed to the last argument of abort callback.
819 |
# File 'sig/whisper.rbs', line 819
def abort_callback_user_data=: (Object?) -> Object?
|
#abort_on { ... } ⇒ void
This method returns an undefined value.
Call block to determine whether abort or not. Return true when you want to abort.
840 |
# File 'sig/whisper.rbs', line 840
def abort_on: { () -> boolish } -> void
|
#audio_ctx ⇒ Integer
762 |
# File 'sig/whisper.rbs', line 762
def audio_ctx: () -> Integer
|
#audio_ctx= ⇒ Integer
Overwrite the audio context size. 0 uses the default value.
761 |
# File 'sig/whisper.rbs', line 761
def audio_ctx=: (Integer) -> Integer
|
#duration_ms ⇒ Integer
752 |
# File 'sig/whisper.rbs', line 752
def duration_ms: () -> Integer
|
#duration_ms= ⇒ Integer
Audio duration to process in ms.
751 |
# File 'sig/whisper.rbs', line 751
def duration_ms=: (Integer) -> Integer
|
#encoder_begin_callback ⇒ (^(Whisper::Parakeet::Context, untyped, Object user_data) -> boolish)?
805 |
# File 'sig/whisper.rbs', line 805
def encoder_begin_callback: () -> ((^(Whisper::Parakeet::Context, untyped, Object user_data) -> boolish) | nil)
|
#encoder_begin_callback= ⇒ ^(Whisper::Parakeet::Context, untyped, Object user_data) -> boolish
Sets encoder begin callback, called each time before the encoder starts.
If it returns false, the computation is aborted.
804 |
# File 'sig/whisper.rbs', line 804
def encoder_begin_callback=: (^(Whisper::Parakeet::Context, untyped, Object user_data) -> boolish) -> (^(Whisper::Parakeet::Context, untyped, Object user_data) -> boolish)
|
#encoder_begin_callback_user_data ⇒ Object?
810 |
# File 'sig/whisper.rbs', line 810
def encoder_begin_callback_user_data: () -> Object?
|
#encoder_begin_callback_user_data= ⇒ Object?
Sets user data passed to the last argument of encoder begin callback.
809 |
# File 'sig/whisper.rbs', line 809
def encoder_begin_callback_user_data=: (Object?) -> Object?
|
#n_threads ⇒ Integer
742 |
# File 'sig/whisper.rbs', line 742
def n_threads: () -> Integer
|
#n_threads= ⇒ Integer
Number of threads to use.
741 |
# File 'sig/whisper.rbs', line 741
def n_threads=: (Integer) -> Integer
|
#new_segment_callback ⇒ (^(Whisper::Parakeet::Context, untyped, Integer n_new, Object user_data) -> void)?
771 |
# File 'sig/whisper.rbs', line 771
def new_segment_callback: () -> ((^(Whisper::Parakeet::Context, untyped, Integer n_new, Object user_data) -> void) | nil)
|
#new_segment_callback= ⇒ ^(Whisper::Parakeet::Context, untyped, Integer n_new, Object user_data) -> void
Sets new segment callback, called for every newly generated text segment.
params.new_segment_callback = ->(context, _, n_new, user_data) {
# ...
}
770 |
# File 'sig/whisper.rbs', line 770
def new_segment_callback=: (^(Whisper::Parakeet::Context, untyped, Integer n_new, Object user_data) -> void) -> (^(Whisper::Parakeet::Context, untyped, Integer n_new, Object user_data) -> void)
|
#new_segment_callback_user_data ⇒ Object?
776 |
# File 'sig/whisper.rbs', line 776
def new_segment_callback_user_data: () -> Object?
|
#new_segment_callback_user_data= ⇒ Object?
Sets user data passed to the last argument of new segment callback.
775 |
# File 'sig/whisper.rbs', line 775
def new_segment_callback_user_data=: (Object?) -> Object?
|
#new_token_callback ⇒ (^(Whisper::Parakeet::Context, untyped, Whisper::Parakeet::Token, Object user_data) -> void)?
781 |
# File 'sig/whisper.rbs', line 781
def new_token_callback: () -> ((^(Whisper::Parakeet::Context, untyped, Whisper::Parakeet::Token, Object user_data) -> void) | nil)
|
#new_token_callback= ⇒ ^(Whisper::Parakeet::Context, untyped, Whisper::Parakeet::Token, Object user_data) -> void
Sets token callback, called for every newly predicted token.
780 |
# File 'sig/whisper.rbs', line 780
def new_token_callback=: (^(Whisper::Parakeet::Context, untyped, Whisper::Parakeet::Token, Object user_data) -> void) -> (^(Whisper::Parakeet::Context, untyped, Whisper::Parakeet::Token, Object user_data) -> void)
|
#new_token_callback_user_data ⇒ Object?
786 |
# File 'sig/whisper.rbs', line 786
def new_token_callback_user_data: () -> Object?
|
#new_token_callback_user_data= ⇒ Object?
Sets user data passed to the last argument of token callback.
785 |
# File 'sig/whisper.rbs', line 785
def new_token_callback_user_data=: (Object?) -> Object?
|
#no_context ⇒ true, false
757 |
# File 'sig/whisper.rbs', line 757
def no_context: () -> (true | false)
|
#no_context= ⇒ boolish
If true, does not use past transcription (if any) as context.
756 |
# File 'sig/whisper.rbs', line 756
def no_context=: (boolish) -> boolish
|
#offset_ms ⇒ Integer
747 |
# File 'sig/whisper.rbs', line 747
def offset_ms: () -> Integer
|
#offset_ms= ⇒ Integer
Start offset in ms.
746 |
# File 'sig/whisper.rbs', line 746
def offset_ms=: (Integer) -> Integer
|
#on_encoder_begin { ... } ⇒ void
This method returns an undefined value.
Hook called each time before the encoder starts.
836 |
# File 'sig/whisper.rbs', line 836
def on_encoder_begin: { () -> boolish } -> void
|
#on_new_segment {|arg0| ... } ⇒ void
This method returns an undefined value.
Hook called on new segment. Yields each Whisper::Parakeet::Segment.
824 |
# File 'sig/whisper.rbs', line 824
def on_new_segment: { (Segment) -> void } -> void
|
#on_new_token {|arg0| ... } ⇒ void
This method returns an undefined value.
Hook called on new token. Yields each Whisper::Parakeet::Token.
828 |
# File 'sig/whisper.rbs', line 828
def on_new_token: { (Token) -> void } -> void
|
#on_progress {|progress| ... } ⇒ void
This method returns an undefined value.
Hook called on progress update. Yields each progress Integer between 0 and 100.
832 |
# File 'sig/whisper.rbs', line 832
def on_progress: { (Integer progress) -> void } -> void
|
#progress_callback ⇒ (^(Whisper::Parakeet::Context, untyped, Integer progress, Object user_data) -> void)?
793 |
# File 'sig/whisper.rbs', line 793
def progress_callback: () -> ((^(Whisper::Parakeet::Context, untyped, Integer progress, Object user_data) -> void) | nil)
|
#progress_callback= ⇒ ^(Whisper::Parakeet::Context, untyped, Integer progress, Object user_data) -> void
Sets progress callback, called on each progress update.
progress is an Integer between 0 and 100.
792 |
# File 'sig/whisper.rbs', line 792
def progress_callback=: (^(Whisper::Parakeet::Context, untyped, Integer progress, Object user_data) -> void) -> (^(Whisper::Parakeet::Context, untyped, Integer progress, Object user_data) -> void)
|
#progress_callback_user_data ⇒ Object?
798 |
# File 'sig/whisper.rbs', line 798
def progress_callback_user_data: () -> Object?
|
#progress_callback_user_data= ⇒ Object?
Sets user data passed to the last argument of progress callback.
797 |
# File 'sig/whisper.rbs', line 797
def progress_callback_user_data=: (Object?) -> Object?
|