Class: Whisper::Parakeet::Token
- Inherits:
-
Object
- Object
- Whisper::Parakeet::Token
- Defined in:
- sig/whisper.rbs
Instance Method Summary collapse
- #deconstruct_keys ⇒ deconstructed_keys
-
#duration_idx ⇒ Integer
Index into the model's durations array.
-
#duration_value ⇒ Integer
Actual duration value.
-
#end_time ⇒ Integer
End time of the token in milliseconds.
-
#frame_index ⇒ Integer
Frame index of the token.
-
#id ⇒ Integer
Token ID.
-
#log_probability ⇒ Float
Log probability of the token.
-
#probability ⇒ Float
Probability of the token.
-
#start_time ⇒ Integer
Start time of the token in milliseconds.
-
#text ⇒ String
Get the token text of the token.
-
#word_start? ⇒ true, false
Whether this token is the start of a word.
Instance Method Details
#deconstruct_keys ⇒ deconstructed_keys
936 |
# File 'sig/whisper.rbs', line 936
def deconstruct_keys: (Array[:id | :duration_idx | :duration_value | :frame_index | :probability | :log_probability | :start_time | :end_time | :word_start | :text] | nil) -> deconstructed_keys
|
#duration_idx ⇒ Integer
Index into the model's durations array.
902 |
# File 'sig/whisper.rbs', line 902
def duration_idx: () -> Integer
|
#duration_value ⇒ Integer
Actual duration value.
906 |
# File 'sig/whisper.rbs', line 906
def duration_value: () -> Integer
|
#end_time ⇒ Integer
End time of the token in milliseconds.
926 |
# File 'sig/whisper.rbs', line 926
def end_time: () -> Integer
|
#frame_index ⇒ Integer
Frame index of the token.
910 |
# File 'sig/whisper.rbs', line 910
def frame_index: () -> Integer
|
#id ⇒ Integer
Token ID.
898 |
# File 'sig/whisper.rbs', line 898
def id: () -> Integer
|
#log_probability ⇒ Float
Log probability of the token.
918 |
# File 'sig/whisper.rbs', line 918
def log_probability: () -> Float
|
#probability ⇒ Float
Probability of the token.
914 |
# File 'sig/whisper.rbs', line 914
def probability: () -> Float
|
#start_time ⇒ Integer
Start time of the token in milliseconds.
922 |
# File 'sig/whisper.rbs', line 922
def start_time: () -> Integer
|
#text ⇒ String
Get the token text of the token.
934 |
# File 'sig/whisper.rbs', line 934
def text: () -> String
|
#word_start? ⇒ true, false
Whether this token is the start of a word.
930 |
# File 'sig/whisper.rbs', line 930
def word_start?: () -> (true | false)
|