Class: Whisper::VAD::Params

Inherits:
Object
  • Object
show all
Defined in:
sig/whisper.rbs

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.newObject



952
# File 'sig/whisper.rbs', line 952

def self.new: (

Instance Method Details

#==true, false

Parameters:

Returns:

  • (true, false)


995
# File 'sig/whisper.rbs', line 995

def ==: (Params) -> (true | false)

#max_speech_duration_sFloat

Returns:

  • (Float)


982
# File 'sig/whisper.rbs', line 982

def max_speech_duration_s: () -> Float

#max_speech_duration_s=Float

Max duration of a speech segment before forcing a new segment.

Parameters:

  • (Float)

Returns:

  • (Float)


980
# File 'sig/whisper.rbs', line 980

def max_speech_duration_s=: (Float) -> Float

#min_silence_duration_msInteger

Returns:

  • (Integer)


977
# File 'sig/whisper.rbs', line 977

def min_silence_duration_ms: () -> Integer

#min_silence_duration_ms=Integer

Min silence duration to consider speech as ended.

Parameters:

  • (Integer)

Returns:

  • (Integer)


975
# File 'sig/whisper.rbs', line 975

def min_silence_duration_ms=: (Integer) -> Integer

#min_speech_duration_msInteger

Returns:

  • (Integer)


971
# File 'sig/whisper.rbs', line 971

def min_speech_duration_ms: () -> Integer

#min_speech_duration_ms=Integer

Min duration for a valid speech segment.

Parameters:

  • (Integer)

Returns:

  • (Integer)


969
# File 'sig/whisper.rbs', line 969

def min_speech_duration_ms=: (Integer) -> Integer

#samples_overlapFloat

Returns:

  • (Float)


994
# File 'sig/whisper.rbs', line 994

def samples_overlap: () -> Float

#samples_overlap=Float

Overlap in seconds when copying audio samples from speech segment.

Parameters:

  • (Float)

Returns:

  • (Float)


992
# File 'sig/whisper.rbs', line 992

def samples_overlap=: (Float) -> Float

#speech_pad_msInteger

Returns:

  • (Integer)


988
# File 'sig/whisper.rbs', line 988

def speech_pad_ms: () -> Integer

#speech_pad_ms=Integer

Padding added before and after speech segments.

Parameters:

  • (Integer)

Returns:

  • (Integer)


986
# File 'sig/whisper.rbs', line 986

def speech_pad_ms=: (Integer) -> Integer

#thresholdFloat

Returns:

  • (Float)


965
# File 'sig/whisper.rbs', line 965

def threshold: () -> Float

#threshold=Float

Probability threshold to consider as speech.

Parameters:

  • (Float)

Returns:

  • (Float)


963
# File 'sig/whisper.rbs', line 963

def threshold=: (Float) -> Float