Class: Whisper::VAD::Params
- Inherits:
-
Object
- Object
- Whisper::VAD::Params
- Defined in:
- sig/whisper.rbs
Class Method Summary collapse
Instance Method Summary collapse
- #== ⇒ true, false
- #max_speech_duration_s ⇒ Float
-
#max_speech_duration_s= ⇒ Float
Max duration of a speech segment before forcing a new segment.
- #min_silence_duration_ms ⇒ Integer
-
#min_silence_duration_ms= ⇒ Integer
Min silence duration to consider speech as ended.
- #min_speech_duration_ms ⇒ Integer
-
#min_speech_duration_ms= ⇒ Integer
Min duration for a valid speech segment.
- #samples_overlap ⇒ Float
-
#samples_overlap= ⇒ Float
Overlap in seconds when copying audio samples from speech segment.
- #speech_pad_ms ⇒ Integer
-
#speech_pad_ms= ⇒ Integer
Padding added before and after speech segments.
- #threshold ⇒ Float
-
#threshold= ⇒ Float
Probability threshold to consider as speech.
Class Method Details
.new ⇒ Object
952 |
# File 'sig/whisper.rbs', line 952
def self.new: (
|
Instance Method Details
#== ⇒ true, false
995 |
# File 'sig/whisper.rbs', line 995
def ==: (Params) -> (true | false)
|
#max_speech_duration_s ⇒ Float
982 |
# File 'sig/whisper.rbs', line 982
def max_speech_duration_s: () -> Float
|
#max_speech_duration_s= ⇒ Float
Max duration of a speech segment before forcing a new segment.
980 |
# File 'sig/whisper.rbs', line 980
def max_speech_duration_s=: (Float) -> Float
|
#min_silence_duration_ms ⇒ Integer
977 |
# File 'sig/whisper.rbs', line 977
def min_silence_duration_ms: () -> Integer
|
#min_silence_duration_ms= ⇒ Integer
Min silence duration to consider speech as ended.
975 |
# File 'sig/whisper.rbs', line 975
def min_silence_duration_ms=: (Integer) -> Integer
|
#min_speech_duration_ms ⇒ Integer
971 |
# File 'sig/whisper.rbs', line 971
def min_speech_duration_ms: () -> Integer
|
#min_speech_duration_ms= ⇒ Integer
Min duration for a valid speech segment.
969 |
# File 'sig/whisper.rbs', line 969
def min_speech_duration_ms=: (Integer) -> Integer
|
#samples_overlap ⇒ Float
994 |
# File 'sig/whisper.rbs', line 994
def samples_overlap: () -> Float
|
#samples_overlap= ⇒ Float
Overlap in seconds when copying audio samples from speech segment.
992 |
# File 'sig/whisper.rbs', line 992
def samples_overlap=: (Float) -> Float
|
#speech_pad_ms ⇒ Integer
988 |
# File 'sig/whisper.rbs', line 988
def speech_pad_ms: () -> Integer
|
#speech_pad_ms= ⇒ Integer
Padding added before and after speech segments.
986 |
# File 'sig/whisper.rbs', line 986
def speech_pad_ms=: (Integer) -> Integer
|
#threshold ⇒ Float
965 |
# File 'sig/whisper.rbs', line 965
def threshold: () -> Float
|
#threshold= ⇒ Float
Probability threshold to consider as speech.
963 |
# File 'sig/whisper.rbs', line 963
def threshold=: (Float) -> Float
|