Class: Whisper::VAD::Params
- Inherits:
-
Object
- Object
- Whisper::VAD::Params
- Defined in:
- sig/whisper.rbs
Class Method Summary collapse
Instance Method Summary collapse
- #== ⇒ true, false
- #max_speech_duration_s ⇒ Float
-
#max_speech_duration_s= ⇒ Float
Max duration of a speech segment before forcing a new segment.
- #min_silence_duration_ms ⇒ Integer
-
#min_silence_duration_ms= ⇒ Integer
Min silence duration to consider speech as ended.
- #min_speech_duration_ms ⇒ Integer
-
#min_speech_duration_ms= ⇒ Integer
Min duration for a valid speech segment.
- #samples_overlap ⇒ Float
-
#samples_overlap= ⇒ Float
Overlap in seconds when copying audio samples from speech segment.
- #speech_pad_ms ⇒ Integer
-
#speech_pad_ms= ⇒ Integer
Padding added before and after speech segments.
- #threshold ⇒ Float
-
#threshold= ⇒ Float
Probability threshold to consider as speech.
Class Method Details
.new ⇒ Object
946 |
# File 'sig/whisper.rbs', line 946
def self.new: (
|
Instance Method Details
#== ⇒ true, false
989 |
# File 'sig/whisper.rbs', line 989
def ==: (Params) -> (true | false)
|
#max_speech_duration_s ⇒ Float
976 |
# File 'sig/whisper.rbs', line 976
def max_speech_duration_s: () -> Float
|
#max_speech_duration_s= ⇒ Float
Max duration of a speech segment before forcing a new segment.
974 |
# File 'sig/whisper.rbs', line 974
def max_speech_duration_s=: (Float) -> Float
|
#min_silence_duration_ms ⇒ Integer
971 |
# File 'sig/whisper.rbs', line 971
def min_silence_duration_ms: () -> Integer
|
#min_silence_duration_ms= ⇒ Integer
Min silence duration to consider speech as ended.
969 |
# File 'sig/whisper.rbs', line 969
def min_silence_duration_ms=: (Integer) -> Integer
|
#min_speech_duration_ms ⇒ Integer
965 |
# File 'sig/whisper.rbs', line 965
def min_speech_duration_ms: () -> Integer
|
#min_speech_duration_ms= ⇒ Integer
Min duration for a valid speech segment.
963 |
# File 'sig/whisper.rbs', line 963
def min_speech_duration_ms=: (Integer) -> Integer
|
#samples_overlap ⇒ Float
988 |
# File 'sig/whisper.rbs', line 988
def samples_overlap: () -> Float
|
#samples_overlap= ⇒ Float
Overlap in seconds when copying audio samples from speech segment.
986 |
# File 'sig/whisper.rbs', line 986
def samples_overlap=: (Float) -> Float
|
#speech_pad_ms ⇒ Integer
982 |
# File 'sig/whisper.rbs', line 982
def speech_pad_ms: () -> Integer
|
#speech_pad_ms= ⇒ Integer
Padding added before and after speech segments.
980 |
# File 'sig/whisper.rbs', line 980
def speech_pad_ms=: (Integer) -> Integer
|
#threshold ⇒ Float
959 |
# File 'sig/whisper.rbs', line 959
def threshold: () -> Float
|
#threshold= ⇒ Float
Probability threshold to consider as speech.
957 |
# File 'sig/whisper.rbs', line 957
def threshold=: (Float) -> Float
|